@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+* Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
@@ -26,17 +26,12 @@
 //================================================================================
 // model_Model
 
-
-void model_Model::init()
-{
+void model_Model::init() {
 }
 
-void model_Model::set_data(ImplData *data)
-{
-  _data= data;
+void model_Model::set_data(ImplData *data) {
+  _data = data;
 }
 
-model_Model::~model_Model()
-{
+model_Model::~model_Model() {
 }
-
