@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,6 +20,6 @@
 #include "grts/structs.wrapper.h"
 #include "grtsqlparser/mysql_parser_services.h"
 
-GRT_STRUCTS_WRAPPER_PUBLIC parser::ParserContext::Ref parser_context_from_grt(parser_ContextReferenceRef object);
-GRT_STRUCTS_WRAPPER_PUBLIC parser_ContextReferenceRef parser_context_to_grt(grt::GRT *grt,
-  const parser::ParserContext::Ref &context);
+GRT_STRUCTS_WRAPPER_PUBLIC parser::MySQLParserContext::Ref parser_context_from_grt(parser_ContextReferenceRef object);
+GRT_STRUCTS_WRAPPER_PUBLIC parser_ContextReferenceRef
+parser_context_to_grt(const parser::MySQLParserContext::Ref &context);
