@@ -1,16 +1,16 @@
-/* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; version 2 of the
  * License.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
@@ -22,17 +22,13 @@
 #include "model_connection_impl.h"
 #include "grts/structs.workbench.physical.h"
 
-
-namespace wbfig
-{
+namespace wbfig {
   class FigureItem;
 };
 
-  
-class WBPUBLICBACKEND_PUBLIC_FUNC workbench_physical_Connection::ImplData : public model_Connection::ImplData
-{
+class WBPUBLICBACKEND_PUBLIC_FUNC workbench_physical_Connection::ImplData : public model_Connection::ImplData {
   typedef model_Connection::ImplData super;
-  
+
 protected:
   boost::signals2::scoped_connection _realize_conn;
 
@@ -44,14 +40,14 @@ protected:
 
   void fk_changed(const db_ForeignKeyRef &fk);
   void member_changed(const std::string &name, const grt::ValueRef &ovalue);
-  
+
   virtual bool realize();
   virtual void unrealize();
-  
+
   void update_line_ends();
   void layout_changed();
   void table_changed(const std::string &detail);
-  
+
   virtual mdc::CanvasItem *get_start_canvas_item();
   virtual mdc::CanvasItem *get_end_canvas_item();
 
@@ -66,8 +62,8 @@ protected:
 public:
   ImplData(workbench_physical_Connection *self);
   virtual ~ImplData();
-  
-  virtual void highlight(const base::Color *color= 0);
+
+  virtual void highlight(const base::Color *color = 0);
   virtual void unhighlight();
 
   virtual void set_in_view(bool flag);
@@ -75,8 +71,9 @@ public:
   void set_foreign_key(const db_ForeignKeyRef &fk);
 
 private:
-  workbench_physical_Connection *self() const { return (workbench_physical_Connection*)_self; }
+  workbench_physical_Connection *self() const {
+    return (workbench_physical_Connection *)_self;
+  }
 };
 
-
 #endif
