@@ -1,16 +1,16 @@
-/* 
- * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; version 2 of the
  * License.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
@@ -25,13 +25,13 @@ typedef __int64 ssize_t;
 typedef int ssize_t;
 #endif
 
-#pragma warning(disable: 4793) // 'vararg' causes native code generation
-#pragma warning(disable: 4996) // 'std::_Uninitialized_copy0': Function call with parameters that may be unsafe
-                               // A warning caused by the usage of boost in this context.
+#pragma warning(disable : 4793) // 'vararg' causes native code generation
+#pragma warning(disable : 4996) // 'std::_Uninitialized_copy0': Function call with parameters that may be unsafe
+                                // A warning caused by the usage of boost in this context.
 
 #pragma comment(lib, "comctl32.lib")
 
-#define WIN32_LEAN_AND_MEAN 
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <WinCrypt.h>
 #include <ShellAPI.h>
@@ -49,7 +49,6 @@ typedef int ssize_t;
 #include <sstream>
 #include <string>
 #include <assert.h>
-#include <hash_map>
 
 #include <cairo/cairo.h>
 #include <cairo/cairo-Win32.h>
@@ -59,8 +58,8 @@ typedef int ssize_t;
 #include <iosfwd>
 #include <fstream>
 
-#include <boost/function.hpp>
 #include <boost/signals2.hpp>
+
 #include <boost/optional.hpp>
 #include <boost/cstdint.hpp>
 
