@@ -6,8 +6,7 @@
 #include "grts/structs.db.mysql.h"
 #include "../../db.mysql/backend/db_mysql_validation_page.h"
 
-class WBPLUGINDBMYSQLBE_PUBLIC_FUNC DbMySQLSync : public Db_plugin, public DbMySQLValidationPage
-{
+class WBPLUGINDBMYSQLBE_PUBLIC_FUNC DbMySQLSync : public Db_plugin, public DbMySQLValidationPage {
 private:
   // options
   std::string _input_filename;
@@ -15,10 +14,9 @@ private:
   std::string _script_to_apply;
 
 public:
-  DbMySQLSync(bec::GRTManager *grtm);
+  DbMySQLSync();
   void set_option(const std::string& name, const std::string& value);
   void start_apply_script_to_db();
 };
 
 #endif // _DB_MYSQL_SQL_SYNC_H_
-
